@@ -185,8 +185,11 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"descripters",
         b"destructible",
         b"di",
+        b"direction",
+        b"directions",
         b"div",
         b"division",
+        b"document",
         b"double-to-string",
         b"downcalls",
         b"duration",
@@ -227,6 +230,9 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"function",
         b"functionprototype",
         b"futex",
+        b"gadget",
+        b"gadgets",
+        b"geo",
         b"gettingstarted",
         b"glob",
         b"global",
@@ -249,6 +255,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"initrd-fs",
         b"initrd-root-fs",
         b"inline",
+        b"input",
         b"install",
         b"int",
         b"int16",
@@ -259,7 +266,11 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"ipconf",
         b"it",
         b"item",
+        b"key",
+        b"keydown",
         b"keyset",
+        b"layer",
+        b"layerswitcher",
         b"legacy",
         b"lexing",
         b"lhash",
@@ -273,6 +284,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"lossy",
         b"manager",
         b"match",
+        b"mem",
         b"memfd",
         b"memutil",
         b"memory",
@@ -280,6 +292,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"metatrace",
         b"method",
         b"metrics",
+        b"microsoft",
         b"mount",
         b"mutex",
         b"multi-user",
@@ -301,6 +314,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"offsets",
         b"og",
         b"once",
+        b"operation",
         b"option",
         b"options",
         b"original",
@@ -327,6 +341,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"process",
         b"profile",
         b"program",
+        b"progress",
         b"property",
         b"proto",
         b"prtime",
@@ -338,7 +353,10 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"reader",
         b"readme",
         b"reboot",
+        b"rect",
+        b"rectangle",
         b"refcount",
+        b"reference",
         b"remote",
         b"remote-fs",
         b"remote-fs-pre",
@@ -390,6 +408,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"strlcpy",
         b"strtod",
         b"strutil",
+        b"sub",
         b"subprocess",
         b"substitute",
         b"swap",
@@ -441,6 +460,8 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"verinfo",
         b"version",
         b"versioninfo",
+        b"view",
+        b"visit",
         b"vlog",
         b"window",
         b"wrapping",
@@ -449,96 +470,448 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"zlib",
         b"zone",
     }
-    # Common variable name ends
-    tld_fpos = {
-        b"at",
-        b"app",
-        b"auto",
-        b"build",
-        b"call",
-        b"cat",
-        b"cc",
-        b"center",
-        b"chrome",
-        b"ci",
-        b"city",
-        b"click",
-        b"country",
-        b"data",
-        b"day",
-        b"delta",
-        b"direct",
-        b"do",
-        b"email",
-        b"events",
-        b"exposed",
-        b"fail",
-        b"foo",
-        b"fun",
-        b"global",
-        b"green",
-        b"group",
-        b"how",
-        b"id",
-        b"in",
-        b"io",
-        b"info",
-        b"is",
-        b"it",
-        b"lat",
-        b"lb",
-        b"link",
-        b"map",
-        b"md",
-        b"mk",
-        b"mobile",
-        b"ms",
-        b"marketing",
-        b"name",
-        b"next",
-        b"now",
-        b"open",
-        b"page",
-        b"pid",
-        b"pl",
-        b"pm",
-        b"play",
-        b"properties",
-        b"py",
-        b"radio",
-        b"read",
-        b"red",
-        b"rs",
-        b"run",
-        b"save",
-        b"search",
-        b"secure",
-        b"security",
-        b"services",
-        b"sh",
-        b"shell",
-        b"so",
-        b"software",
-        b"spa",
-        b"space",
-        b"store",
-        b"stream",
-        b"style",
-        b"support",
-        b"tab",
-        b"target",
-        b"total",
-        b"top",
-        b"xxx",
-        b"zone",
+    reliable_tlds = {
+        # Original tlds
+        b"com",
+        b"net",
+        b"org",
+        b"edu",
+        b"mil",
+        b"gov",
+        b"arpa",
+        # Country tlds, filtered for common fpos
+        b"ac",
+        b"ad",
+        b"ae",
+        b"af",
+        b"ag",
+        b"ai",
+        b"al",
+        b"am",
+        b"ao",
+        b"aq",
+        b"ar",
+        b"au",
+        b"aw",
+        b"ax",
+        b"az",
+        b"ba",
+        b"bd",
+        b"be",
+        b"bf",
+        b"bg",
+        b"bh",
+        b"bi",
+        b"bj",
+        b"bm",
+        b"bn",
+        b"bo",
+        b"br",
+        b"bs",
+        b"bt",
+        b"bv",
+        b"bw",
+        b"by",
+        b"bz",
+        b"ca",
+        b"cd",
+        b"cf",
+        b"cg",
+        b"ch",
+        b"ck",
+        b"cl",
+        b"cm",
+        b"cn",
+        b"co",
+        b"cr",
+        b"cu",
+        b"cv",
+        b"cw",
+        b"cx",
+        b"cy",
+        b"cz",
+        b"de",
+        b"dj",
+        b"dk",
+        b"dm",
+        b"dz",
+        b"ec",
+        b"er",
+        b"es",
+        b"et",
+        b"eu",
+        b"fi",
+        b"fj",
+        b"fk",
+        b"fm",
+        b"fo",
+        b"fr",
+        b"ga",
+        b"gb",
+        b"gd",
+        b"ge",
+        b"gl",
+        b"gm",
+        b"gn",
+        b"gp",
+        b"gq",
+        b"gr",
+        b"gs",
+        b"gt",
+        b"gu",
+        b"gw",
+        b"gy",
+        b"hk",
+        b"hm",
+        b"hn",
+        b"hr",
+        b"ht",
+        b"hu",
+        b"ie",
+        b"il",
+        b"im",
+        b"iq",
+        b"ir",
+        b"je",
+        b"jm",
+        b"jo",
+        b"jp",
+        b"ke",
+        b"kg",
+        b"kh",
+        b"ki",
+        b"km",
+        b"kn",
+        b"kp",
+        b"kr",
+        b"kw",
+        b"ky",
+        b"kz",
+        b"la",
+        b"lc",
+        b"li",
+        b"lk",
+        b"lr",
+        b"ls",
+        b"lt",
+        b"lu",
+        b"lv",
+        b"ly",
+        b"ma",
+        b"mc",
+        b"me",
+        b"mg",
+        b"mh",
+        b"ml",
+        b"mn",
+        b"mo",
+        b"mp",
+        b"mq",
+        b"mr",
+        b"mt",
+        b"mu",
+        b"mv",
+        b"mw",
+        b"mx",
+        b"my",
+        b"mz",
+        b"na",
+        b"nc",
+        b"ne",
+        b"nf",
+        b"ng",
+        b"ni",
+        b"nl",
+        b"np",
+        b"nr",
+        b"nu",
+        b"nz",
+        b"om",
+        b"pa",
+        b"pe",
+        b"pf",
+        b"pg",
+        b"ph",
+        b"pk",
+        b"pn",
+        b"pr",
+        b"ps",
+        b"pt",
+        b"pw",
+        b"qa",
+        b"re",
+        b"ro",
+        b"ru",
+        b"rw",
+        b"sa",
+        b"sb",
+        b"sc",
+        b"sd",
+        b"se",
+        b"sg",
+        b"si",
+        b"sj",
+        b"sk",
+        b"sl",
+        b"sm",
+        b"sn",
+        b"sr",
+        b"ss",
+        b"st",
+        b"su",
+        b"sv",
+        b"sx",
+        b"sy",
+        b"sz",
+        b"tc",
+        b"td",
+        b"tf",
+        b"tg",
+        b"th",
+        b"tj",
+        b"tk",
+        b"tl",
+        b"tm",
+        b"tn",
+        b"to",
+        b"tr",
+        b"tt",
+        b"tv",
+        b"tw",
+        b"tz",
+        b"ua",
+        b"ug",
+        b"uk",
+        b"us",
+        b"uy",
+        b"uz",
+        b"va",
+        b"vc",
+        b"ve",
+        b"vg",
+        b"vi",
+        b"vn",
+        b"vu",
+        b"wf",
+        b"ws",
+        b"ye",
+        b"yt",
+        b"za",
+        b"zm",
+        b"zw",
+        # Chinsese ICANN TLDs
+        b"ren",
+        b"shouji",
+        b"tushu",
+        b"wanggou",
+        b"weibo",
+        b"xihuan",
+        b"xin",
+        # French ICANN TLDs
+        b"arte",
+        b"clinique",
+        b"luxe",
+        b"maison",
+        b"moi",
+        b"rsvp",
+        b"sarl",
+        # German ICANN tlds
+        b"epost",
+        b"gmbh",
+        b"haus",
+        b"immobilien",
+        b"jetzt",
+        b"kaufen",
+        b"kinder",
+        b"reise",
+        b"reisen",
+        b"schule",
+        b"versicherung",
+        # Hindi ICANN tlds
+        b"desi",
+        b"shiksha",
+        # Italian ICANN tlds
+        b"casa",
+        b"immo",
+        b"moda",
+        b"voto",
+        # Portuguese ICANN tlds
+        b"bom",
+        b"passagens"
+        # Spanish ICANN tlds
+        b"abogado",
+        b"futbol",
+        b"gratis",
+        b"hoteles",
+        b"juegos",
+        b"ltda",
+        b"soy",
+        b"tienda",
+        b"uno",
+        b"viajes",
+        b"vuelos",
+        # International TLDs
+        b"xn--11b4c3d",
+        b"xn--1ck2e1b",
+        b"xn--1qqw23a",
+        b"xn--2scrj9c",
+        b"xn--30rr7y",
+        b"xn--3bst00m",
+        b"xn--3ds443g",
+        b"xn--3e0b707e",
+        b"xn--3hcrj9c",
+        b"xn--3pxu8k",
+        b"xn--42c2d9a",
+        b"xn--45br5cyl",
+        b"xn--45brj9c",
+        b"xn--45q11c",
+        b"xn--4dbrk0ce",
+        b"xn--4gbrim",
+        b"xn--54b7fta0cc",
+        b"xn--55qw42g",
+        b"xn--55qx5d",
+        b"xn--5su34j936bgsg",
+        b"xn--5tzm5g",
+        b"xn--6frz82g",
+        b"xn--6qq986b3xl",
+        b"xn--80adxhks",
+        b"xn--80ao21a",
+        b"xn--80aqecdr1a",
+        b"xn--80asehdb",
+        b"xn--80aswg",
+        b"xn--8y0a063a",
+        b"xn--90a3ac",
+        b"xn--90ae",
+        b"xn--90ais",
+        b"xn--9dbq2a",
+        b"xn--9et52u",
+        b"xn--9krt00a",
+        b"xn--b4w605ferd",
+        b"xn--bck1b9a5dre4c",
+        b"xn--c1avg",
+        b"xn--c2br7g",
+        b"xn--cck2b3b",
+        b"xn--cckwcxetd",
+        b"xn--cg4bki",
+        b"xn--clchc0ea0b2g2a9gcd",
+        b"xn--czr694b",
+        b"xn--czrs0t",
+        b"xn--czru2d",
+        b"xn--d1acj3b",
+        b"xn--d1alf",
+        b"xn--e1a4c",
+        b"xn--eckvdtc9d",
+        b"xn--efvy88h",
+        b"xn--fct429k",
+        b"xn--fhbei",
+        b"xn--fiq228c5hs",
+        b"xn--fiq64b",
+        b"xn--fiqs8s",
+        b"xn--fiqz9s",
+        b"xn--fjq720a",
+        b"xn--flw351e",
+        b"xn--fpcrj9c3d",
+        b"xn--fzc2c9e2c",
+        b"xn--fzys8d69uvgm",
+        b"xn--g2xx48c",
+        b"xn--gckr3f0f",
+        b"xn--gecrj9c",
+        b"xn--gk3at1e",
+        b"xn--h2breg3eve",
+        b"xn--h2brj9c",
+        b"xn--h2brj9c8c",
+        b"xn--hxt814e",
+        b"xn--i1b6b1a6a2e",
+        b"xn--imr513n",
+        b"xn--io0a7i",
+        b"xn--j1aef",
+        b"xn--j1amh",
+        b"xn--j6w193g",
+        b"xn--jlq480n2rg",
+        b"xn--jvr189m",
+        b"xn--kcrx77d1x4a",
+        b"xn--kprw13d",
+        b"xn--kpry57d",
+        b"xn--kput3i",
+        b"xn--l1acc",
+        b"xn--lgbbat1ad8j",
+        b"xn--mgb9awbf",
+        b"xn--mgba3a3ejt",
+        b"xn--mgba3a4f16a",
+        b"xn--mgba7c0bbn0a",
+        b"xn--mgbaam7a8h",
+        b"xn--mgbab2bd",
+        b"xn--mgbah1a3hjkrd",
+        b"xn--mgbai9azgqp6j",
+        b"xn--mgbayh7gpa",
+        b"xn--mgbbh1a",
+        b"xn--mgbbh1a71e",
+        b"xn--mgbc0a9azcg",
+        b"xn--mgbca7dzdo",
+        b"xn--mgbcpq6gpa1a",
+        b"xn--mgberp4a5d4ar",
+        b"xn--mgbgu82a",
+        b"xn--mgbi4ecexp",
+        b"xn--mgbpl2fh",
+        b"xn--mgbt3dhd",
+        b"xn--mgbtx2b",
+        b"xn--mgbx4cd0ab",
+        b"xn--mix891f",
+        b"xn--mk1bu44c",
+        b"xn--mxtq1m",
+        b"xn--ngbc5azd",
+        b"xn--ngbe9e0a",
+        b"xn--ngbrx",
+        b"xn--node",
+        b"xn--nqv7f",
+        b"xn--nqv7fs00ema",
+        b"xn--nyqy26a",
+        b"xn--o3cw4h",
+        b"xn--ogbpf8fl",
+        b"xn--otu796d",
+        b"xn--p1acf",
+        b"xn--p1ai",
+        b"xn--pgbs0dh",
+        b"xn--pssy2u",
+        b"xn--q7ce6a",
+        b"xn--q9jyb4c",
+        b"xn--qcka1pmc",
+        b"xn--qxa6a",
+        b"xn--qxam",
+        b"xn--rhqv96g",
+        b"xn--rovu88b",
+        b"xn--rvc1e0am3e",
+        b"xn--s9brj9c",
+        b"xn--ses554g",
+        b"xn--t60b56a",
+        b"xn--tckwe",
+        b"xn--tiq49xqyj",
+        b"xn--unup4y",
+        b"xn--vermgensberater-ctb",
+        b"xn--vermgensberatung-pwb",
+        b"xn--vhquv",
+        b"xn--vuq861b",
+        b"xn--w4r85el8fhu5dnra",
+        b"xn--w4rs40l",
+        b"xn--wgbh1c",
+        b"xn--wgbl6a",
+        b"xn--xhq521b",
+        b"xn--xkc2al3hye2a",
+        b"xn--xkc2dl3a5ee0h",
+        b"xn--y9a3aq",
+        b"xn--yfro4i67o",
+        b"xn--ygbi2ammx",
+        b"xn--zfr164b",
     }
     return bool(
-        (tld == b"next" and b"iterator" in domain_lower)  # Iterator not domain
-        or re.match(b"[a-z]+[.][A-Z][a-z]+", domain)  # attribute access not domain
-        or (tld in tld_fpos and (root in root_fpos or len(root) == 1))  # variable attribute
-        or domain_lower.startswith(b"this.")  # super common variable name in javascript
-        or (len(split) == 3 and split[1] == b"prototype" and len(root) < 3 and len(tld) < 3)  # javascript pattern
+        len(root) < 3  # difficult to register, common variable names
+        or root == b"this"  # common variable name in javascript
         or (domain_lower.startswith(b"lib") and tld == b"so")  # ELF false positive
+        or (root in root_fpos and tld not in reliable_tlds)  # variable attribute
+        or (tld == b"next" and b"iterator" in domain_lower)  # Iterator not domain
+        or re.match(b"[a-z]+[.][A-Z][a-z]+", domain)  # attribute access not domain
+        or (len(split) == 3 and split[1] == b"prototype" and len(root) < 3 and len(tld) < 3)  # javascript pattern
+        or domain_lower.endswith(b"prototype.at")
     )
 
 
@@ -549,6 +922,23 @@ def find_domains(data: bytes) -> list[Node]:
     out = []
     for match in re.finditer(DOMAIN_RE, data):
         domain = match.group()
+
+        # Check if the preceeding character where this domain was found in the data is a "%"
+        # Some of the URL encoding might be stuck to the domain that was found via regex.
+        preceeding_character = chr(data[match.start() - 1])
+        next_character = chr(data[match.end()]) if match.end() < len(data) else None
+        if next_character and next_character == "@":
+            # If the next character is an '@', we are in a userinfo section of a URL or email address.
+            # The domain of interest should follow after the "@" in either scenario (which is likely captured by regex)
+            continue
+
+        if preceeding_character == "%" and domain.lower().startswith((b"2f", b"40")):
+            # If it is, we need to remove the trailing characters that follow as that's not part of the actual domain.
+            domain = domain[2:]
+
+            # Update the match object to reflect the new domain
+            match = re.search(domain, data, 0, *match.span())
+
         if not is_domain(domain) or len(domain) < 7:
             continue
         if domain_is_false_positive(domain):
@@ -602,6 +992,7 @@ def find_urls(data: bytes) -> list[Node]:
         group = match.group()
         start, end = match.span()
         prev = data[start - 1]
+        next_chr = data[end + 1] if end + 1 < len(data) else None
         if start == 0:
             pass  # No context
         elif group[prev : prev + 1] == b"0" and not _is_printable(data[start - 10 : start]):
@@ -613,6 +1004,13 @@ def find_urls(data: bytes) -> list[Node]:
             if close > -1:
                 end = start + close
                 group = group[:close]
+        elif next_chr and prev == ord('"') and prev != next_chr:
+            # URL is part of a quoted string but not the whole string was extracted
+            # Common for XML or HTML files
+            match = re.match(rb'[a-zA-Z0-9\s\.\/]+"', data, pos=end)
+            if match:
+                end = match.end() - 1
+                group = data[start:end]
         if not is_url(group):
             continue
         out.append(
