@@ -187,6 +187,16 @@ def test_DOMAIN_RE_context(data, domain):
         b"readme.md",
         b"compile.sh",
         b"authentication.click",
+        b"system.management",
+        b"microsoft.powershell.security",
+        b"mem.total",
+        b"e.business",
+        b"t.center",
+        b"a.family",
+        b"e.global",
+        b"view.name",
+        b"x.properties",
+        b"sub.name",
     ],
 )
 def test_domain_is_false_positive(domain):
@@ -203,6 +213,14 @@ def test_find_domain_fpos(data):
     assert find_domains(data) == []
 
 
+@pytest.mark.parametrize(
+    ("data", "domains"),
+    [(b"K.cA", []), (b"mailto:delete.me@cyber.gc.ca", [Node("network.domain", b"cyber.gc.ca", "", 17, 28)])],
+)
+def test_find_domains(data, domains):
+    assert find_domains(data) == domains
+
+
 # Email -----------------------------------------
 
 
@@ -403,6 +421,29 @@ def test_is_url():
                 )
             ],
         ),
+        (
+            b'<a href="https://journal.com/Canadian Centre for Cyber Security/My Great Article.docx">Click Here</a>',
+            [
+                Node(
+                    "network.url",
+                    b"https://journal.com/Canadian Centre for Cyber Security/My Great Article.docx",
+                    "",
+                    9,
+                    85,
+                    children=[
+                        Node("network.url.scheme", b"https", "", 0, 5),
+                        Node("network.domain", b"journal.com", "", 8, 19),
+                        Node(
+                            "network.url.path",
+                            b"/Canadian Centre for Cyber Security/My Great Article.docx",
+                            "",
+                            19,
+                            76,
+                        ),
+                    ],
+                )
+            ],
+        ),
     ],
 )
 def test_find_url(data, urls):
